# diagrid clusters dapr install

Install Dapr in a cluster

```
diagrid clusters dapr install <cluster-id> [flags]
```

### Examples

```

  # NOTE: Dapr must not be already installed in the target cluster

  # Install Dapr version 1.8.4 in a cluster using the dev profile
  diagrid conductor clusters dapr install <cluster-id> --version 1.8.4 --profile dev

  # Install Dapr version 1.8.4 in a cluster using the dev profile and rollout all Dapr enabled apps
  diagrid conductor clusters dapr install <cluster-id> --version 1.8.4 --profile dev --rollout-all

  # Install Dapr in a cluster using a custom Helm values file and rollout all Dapr enabled apps
  diagrid conductor clusters dapr install <cluster-id> --version 1.8.4 -f my-helm-values.yaml --rollout-all

```

### Options

```
      --api-key string            Diagrid Cloud API key
      --helm-repository string    custom dapr helm repository. Leave empty to use 'ghcr.io/dapr'
  -f, --helm-values-file string   Custom Helm values.yaml filepath
  -h, --help                      help for install
      --namespace string          Dapr namespace (default "dapr-system")
  -o, --output string             Output format, supported [table, yaml, json] (default "table")
  -p, --profile string            Profile for installing Dapr (dev, prod)
  -r, --rollout-all               Enable the rollout of all Dapr applications after a Dapr config update
  -v, --version string            Dapr version to be installed (default "1.9.3")
```

### SEE ALSO

- [diagrid clusters dapr](./dapr.md)	 - Manage the Dapr control plane deployment
